/*******************************************************************************
 * Copyright (c) 2007 Actuate Corporation.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *  Actuate Corporation  - initial API and implementation
 *******************************************************************************/

package org.birt.cb;

import java.util.Iterator;
import java.util.List;

import org.eclipse.birt.chart.exception.ChartException;
import org.eclipse.birt.chart.model.data.Query;
import org.eclipse.birt.chart.ui.swt.ColumnBindingInfo;
import org.eclipse.birt.chart.ui.swt.CustomPreviewTable;
import org.eclipse.birt.chart.ui.swt.DefaultChartDataSheet;
import org.eclipse.birt.chart.ui.swt.SimpleTextTransfer;
import org.eclipse.birt.chart.ui.swt.interfaces.IDataServiceProvider;
import org.eclipse.birt.chart.ui.swt.interfaces.ISelectDataCustomizeUI;
import org.eclipse.birt.chart.ui.swt.wizard.data.SelectDataDynamicArea;
import org.eclipse.birt.chart.ui.util.ChartUIConstants;
import org.eclipse.birt.chart.ui.util.ChartUIUtil;
import org.eclipse.birt.core.data.ExpressionUtil;
import org.eclipse.birt.core.ui.frameworks.taskwizard.interfaces.ITask;
import org.eclipse.jface.resource.JFaceResources;
import org.eclipse.swt.SWT;
import org.eclipse.swt.dnd.DND;
import org.eclipse.swt.dnd.DragSource;
import org.eclipse.swt.dnd.DragSourceEvent;
import org.eclipse.swt.dnd.DragSourceListener;
import org.eclipse.swt.dnd.Transfer;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Event;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Listener;

/**
 * 
 */

public class SampleStandardDataSheet extends DefaultChartDataSheet implements
Listener
{

	private IDataServiceProvider dataProvider;
	private ColumnBindingInfo[] cols;
	private CustomPreviewTable tablePreview = null;

	public SampleStandardDataSheet( IDataServiceProvider dataProvider )
	{
		this.dataProvider = dataProvider;
	}

	public Composite createDataDragSource( Composite parent )
	{
		ColumnBindingInfo[] columnHeaders = null;
		String[] cols = ((DefaultDataServiceProviderImpl)dataProvider).getPreviewHeader();
		columnHeaders = new ColumnBindingInfo[cols.length];
		                                      
		                                      
		Composite composite = ChartUIUtil.createCompositeWrapper( parent );
		{
			composite.setLayoutData( new GridData( GridData.FILL_BOTH ) );
		}
		Label label = new Label( composite, SWT.NONE );
		{
			label.setText( "Data Preview" );
			label.setFont( JFaceResources.getBannerFont( ) );
		}
		Label description = new Label( composite, SWT.WRAP );
		{
			GridData gd = new GridData( GridData.FILL_HORIZONTAL );
			description.setLayoutData( gd );
			description.setText( "Drag" );
		}

		tablePreview = new CustomPreviewTable( composite, SWT.SINGLE
				| SWT.H_SCROLL | SWT.V_SCROLL | SWT.FULL_SELECTION );
		{
			GridData gridData = new GridData( GridData.FILL_BOTH );
			gridData.widthHint = 400;
			gridData.heightHint = 120;
			tablePreview.setLayoutData( gridData );
			tablePreview.setHeaderAlignment( SWT.LEFT );
			//tablePreview.setColumns(((DefaultDataServiceProviderImpl)dataProvider).getPreviewHeader());
			for( int idx=0; idx < cols.length; idx++){
				columnHeaders[idx] = new ColumnBindingInfo( cols[idx],
						cols[idx], // Use expression for group.
					ColumnBindingInfo.COMMON_COLUMN,
					ChartUIConstants.IMAGE_TASK_DATA, //$NON-NLS-1$
					"",
					null );	
			}
			tablePreview.setColumns(columnHeaders);
			List dataList = ((DefaultDataServiceProviderImpl)dataProvider).getPreviewData();
			
			if ( dataList != null )
			{
				for ( Iterator<?> iterator = dataList.iterator( ); iterator.hasNext( ); )
				{
					String[] dataRow = (String[]) iterator.next( );
					for ( int i = 0; i < dataRow.length; i++ )
					{
						tablePreview.addEntry( dataRow[i], i );
					}
				}
			}
			tablePreview.update();
			//updateDragDataSource( );
			
		}
		
		final DragSource dragSource = new DragSource( tablePreview,
				DND.DROP_COPY );
		dragSource.setTransfer( new Transfer[]{
			SimpleTextTransfer.getInstance( )
		} );
		dragSource.addDragListener( new DragSourceListener( ) {

			private String text = null;

			public void dragFinished( DragSourceEvent event )
			{
				int tst = 5;
				System.out.println(tst);
				// TODO Auto-generated method stub

			}

			public void dragSetData( DragSourceEvent event )
			{
				event.data = text;
			}

			public void dragStart( DragSourceEvent event )
			{
				text = "hello";//createCubeExpression( );
				if ( text == null )
				{
					event.doit = false;
				}
			}
		} );		
		
		
		return composite;
	}

	private DefaultDataServiceProviderImpl getDataServiceProvider( )
	{
		return (DefaultDataServiceProviderImpl) dataProvider;
	}

	public ISelectDataCustomizeUI createCustomizeUI( ITask task )
	{
		return new SelectDataDynamicArea( task );
	}
	

	private synchronized List<?> getPreviewData( ) throws ChartException
	{
		return getDataServiceProvider( ).getPreviewData( );
	}

	public void handleEvent(Event arg0) {
		
		System.out.println("event");
		// TODO Auto-generated method stub
		
	}
	public void setQuery( String qry ){
		Query query = ChartUIUtil.getAllOrthogonalSeriesDefinitions( getContext( ).getModel( ) )
		.get( 0 )
		.getDesignTimeSeries( )
		.getDataDefinition( )
		.get( 0 );
		query.setDefinition(qry);
	}
	
}
